@@ -79,9 +79,9 @@ of 'Error'.
 _DOC_ERRORS = ['enchnt','enchnt','incant','fr']
 
 # Make version info available
-__ver_major__ = 1
-__ver_minor__ = 6
-__ver_patch__ = 7
+__ver_major__ = 2
+__ver_minor__ = 0
+__ver_patch__ = 0
 __ver_sub__ = ""
 __version__ = "%d.%d.%d%s" % (__ver_major__,__ver_minor__,
                               __ver_patch__,__ver_sub__)
@@ -479,7 +479,10 @@ class Broker(_EnchantObject):
         provider backends.  See the method 'set_param' for more details.
         """
         name = EnchantStr(name)
-        return name.decode(_e.broker_get_param(self._this,name.encode()))
+        param = _e.broker_get_param(self._this,name.encode())
+        if param is not None:
+            param = name.decode(param)
+        return param
     get_param._DOC_ERRORS = ["param"]
 
     def set_param(self,name,value):
@@ -490,9 +493,10 @@ class Broker(_EnchantObject):
         any directories given in the "enchant.myspell.dictionary.path"
         parameter when looking for its dictionary files.
         """
-        name = EnchantStr(name)
-        value = EnchantStr(value)
-        _e.broker_set_param(self._this,name.encode(),value.encode())
+        name = EnchantStr(name).encode()
+        if value is not None:
+            value = EnchantStr(value).encode()
+        _e.broker_set_param(self._this,name,value)
 
 
 
@@ -711,15 +715,6 @@ class Dict(_EnchantObject):
         word = self._StringClass(word)
         return _e.dict_is_removed(self._this,word.encode())
 
-    def is_in_session(self,word):
-        """Check whether a word is in the session list."""
-        warnings.warn("Dict.is_in_session is deprecated, "\
-                      "please use Dict.is_added",
-                      category=DeprecationWarning,stacklevel=2)
-        self._check_this()
-        word = self._StringClass(word)
-        return _e.dict_is_in_session(self._this,word.encode())
-
     def store_replacement(self,mis,cor):
         """Store a replacement spelling for a miss-spelled word.
 
@@ -934,10 +929,14 @@ def get_enchant_version():
 
 
 # Run unit tests when called from command-line
-if __name__ == "__main__":
+def _runtestsuite():
     import sys
     import enchant.tests
     res = enchant.tests.runtestsuite()
     if len(res.errors) > 0 or len(res.failures) > 0:
         sys.exit(1)
     sys.exit(0)
+
+
+if __name__ == "__main__":
+    _runtestsuite()
